@@ -346,10 +346,14 @@ def results(
             abort=True,
         )
 
-    simulations_api = SimulationsApi(ctx.obj.api_client)
-    threedimodels_api = ThreedimodelsApi(ctx.obj.api_client)
+    try:
+        simulations_api = SimulationsApi(ctx.obj.api_client)
+        threedimodels_api = ThreedimodelsApi(ctx.obj.api_client)
 
-    simulation = simulations_api.simulations_read(id=simulation)
+        simulation = simulations_api.simulations_read(id=simulation)
+    except ApiException as err:
+        console.print(f"{err}", style="error")
+        sys.exit(ExitCodes.RETRIEVE_ERROR.value)
     threedi_model_id = simulation.threedimodel_id
 
     gridadmin_download = threedimodels_api.threedimodels_gridadmin_download(
