@@ -12,6 +12,7 @@ from . import initial_waterlevels
 from . import structure_control
 from . import boundary_conditions
 from . import leakage
+from . import settings
 
 # Define a list of WRAPPERS
 # A wrapper is an object that 'wraps' a certain
@@ -37,4 +38,5 @@ WRAPPERS = (
     + structure_control.WRAPPERS
     + boundary_conditions.WRAPPERS
     + leakage.WRAPPERS
+    + settings.WRAPPERS
 )
